@@ -351,7 +351,8 @@ print.meta <- function(x,
                    p.ci(format.NA(round(lowTE, digits), digits, "NA"),
                         format.NA(round(uppTE, digits), digits, "NA")),
                    if (comb.fixed) format.NA(w.fixed.p, digits.weight),
-                   if (comb.random) format.NA(w.random.p, digits.weight))
+                   if (comb.random) format.NA(w.random.p, digits.weight),
+                   if (!is.null(x$byvar)) x$byvar)
       ## Printout for a single proportion:
       if (k.all == 1) {
         ##
@@ -372,7 +373,8 @@ print.meta <- function(x,
             cat(method.ci.details)
             dimnames(res) <- list("", c(sm.lab, ci.lab,
                                         if (comb.fixed) "%W(fixed)",
-                                        if (comb.random) "%W(random)"))
+                                        if (comb.random) "%W(random)",
+                                        if (!is.null(x$byvar)) x$bylab))
             prmatrix(res, quote = FALSE, right = TRUE)
             cat("\n\n")
           }
@@ -383,7 +385,8 @@ print.meta <- function(x,
         dimnames(res) <-
           list(x$studlab, c(sm.lab, ci.lab,
                             if (comb.fixed) "%W(fixed)",
-                            if (comb.random) "%W(random)"))
+                            if (comb.random) "%W(random)",
+                            if (!is.null(x$byvar)) x$bylab))
         prmatrix(res[order(sortvar),], quote = FALSE, right = TRUE)
       }
     }
